@@ -15,8 +15,8 @@
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
 #ifndef __XFDESKTOP_FILE_UTILS_H__
@@ -39,9 +39,6 @@ GKeyFile *xfdesktop_file_utils_query_key_file(GFile *file,
 gchar *xfdesktop_file_utils_get_display_name(GFile *file,
                                              GFileInfo *info);
 
-gboolean xfdesktop_file_utils_volume_is_present(GVolume *volume);
-gboolean xfdesktop_file_utils_volume_is_removable(GVolume *volume);
-
 GList *xfdesktop_file_utils_file_icon_list_to_file_list(GList *icon_list);
 GList *xfdesktop_file_utils_file_list_from_string(const gchar *string);
 gchar *xfdesktop_file_utils_file_list_to_string(GList *file_list);
@@ -50,10 +47,9 @@ void xfdesktop_file_utils_file_list_free(GList *file_list);
 
 GdkPixbuf *xfdesktop_file_utils_get_fallback_icon(gint size);
 
-GdkPixbuf *xfdesktop_file_utils_get_icon(const gchar *custom_icon_name,
-                                         GIcon *icon,
-                                         gint size,
-                                         const GdkPixbuf *emblem,
+GdkPixbuf *xfdesktop_file_utils_get_icon(GIcon *icon,
+                                         gint width,
+                                         gint height,
                                          guint opacity);
 
 void xfdesktop_file_utils_set_window_cursor(GtkWindow *window,
@@ -71,6 +67,10 @@ void xfdesktop_file_utils_open_folder(GFile *file,
 void xfdesktop_file_utils_rename_file(GFile *file,
                                       GdkScreen *screen,
                                       GtkWindow *parent);
+void xfdesktop_file_utils_bulk_rename(GFile *working_directory,
+                                      GList *files,
+                                      GdkScreen *screen,
+                                      GtkWindow *parent);
 void xfdesktop_file_utils_trash_files(GList *files,
                                        GdkScreen *screen,
                                        GtkWindow *parent);
@@ -115,6 +115,7 @@ gboolean xfdesktop_file_utils_transfer_files(GdkDragAction action,
 gboolean xfdesktop_file_utils_dbus_init(void);
 DBusGProxy *xfdesktop_file_utils_peek_trash_proxy(void);
 DBusGProxy *xfdesktop_file_utils_peek_filemanager_proxy(void);
+DBusGProxy *xfdesktop_file_utils_peek_thunar_proxy(void);
 void xfdesktop_file_utils_dbus_cleanup(void);
 
 
