@@ -375,7 +375,7 @@ xfdesktop_volume_icon_get_allowed_drop_actions(XfdesktopIcon *icon,
             if(g_file_info_get_attribute_boolean(info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE)) {
                 if(suggested_action)
                     *suggested_action = GDK_ACTION_COPY;
-                return GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK;
+                return GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK | GDK_ACTION_ASK;
             }
         }
     }
